{% extends "pages/base.html" %} {% load i18n static %} {% block title %}{% trans "Edit" %} {{ title }}{% endblock %} {% block extra_head %}
{% endblock %} {% block content %}

# {% trans "Edit document" %}

{% trans "Back to reader" %}
{% if relative_path %}

{% blocktrans trimmed with path=relative_path %} Editing `{{ path }}` {% endblocktrans %}

{% endif %} {% if messages %} {% for message in messages %}
{{ message }}
{% endfor %} {% endif %} {% csrf_token %} {% if form.non_field_errors %}
{{ form.non_field_errors }}
{% endif %}
{% trans "Document content" %} {{ form.content }} {% if form.content.errors %}
{{ form.content.errors|join:', ' }}
{% endif %}
{% trans "Markdown syntax is supported. Changes are saved to the underlying file immediately." %}
{% trans "Cancel" %}
{% endblock %} {% block extra_scripts %}
{% endblock %}